xnet-package: Two-step kernel ridge regression for network analysis

Description Author(s) See Also

Description

This package implements the two-step kernel ridge regression model, a supervised network prediction method that can be used for all kinds of network analyses. Examples are protein-protein interaction, foodwebs, ...

Author(s)

Joris Meys and Michiel Stock

See Also

Send your bug reports to:

https://github.com/CenterForStatistics-UGent/xnet/issues

More background in the paper by Stock et al, 2018:

http://doi.org/10.1093/bib/bby095


CenterForStatistics-UGent/xnet documentation built on June 4, 2021, 4:52 p.m.